function [fleft,gright]=jinxin_flux(u,v,fisico)
%
% Compute the numerical flux in characteristic variables for the convective 
% step of Jin Xin system. Store F(i+1/2) in F(i)
%
% Compute the boundary extrapolated data
% Store F^-(j+1/2) and G^+(j+1/2) in FLEFT(j), GRIGHT(j)
% Add one boundary point to the computational domain

i_f=[fisico(1)-1, fisico];
i_rec=[fisico(1)-1, fisico, fisico(length(fisico))+1];
%
% Compute the value f^-_{j+1/2} for the first characteristic variable
sr(i_rec) = u(i_rec+1)-u(i_rec);
sl(i_rec) = u(i_rec)-u(i_rec-1);
sign_l=sign(sl);
sign_r=sign(sr);
% MinMod limiter
s=0.5*(sign_l+sign_r);
slope=s.*min(abs(sl),abs(sr));
% Central slope
%slope=0.5*(sl+sr);
fleft(i_f) = u(i_f)+ slope(i_f)/2;
%
% Compute the value g^+_{j+1/2} for the second characteristic variable
sr(i_rec) = v(i_rec+1)-v(i_rec);
sl(i_rec) = v(i_rec)-v(i_rec-1);
sign_l=sign(sl);
sign_r=sign(sr);
% MinMod limiter
s=0.5*(sign_l+sign_r);
slope=s.*min(abs(sl),abs(sr));
% Central slope
%slope=0.5*(sl+sr);
gright(i_f) = v(i_f+1)- slope(i_f+1)/2;
